"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import lakefs_client
from lakefs_client.api.otf_diff_api import OtfDiffApi  # noqa: E501


class TestOtfDiffApi(unittest.TestCase):
    """OtfDiffApi unit test stubs"""

    def setUp(self):
        self.api = OtfDiffApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_otf_diff(self):
        """Test case for otf_diff

        perform otf diff  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
